RwSpinLock

Struct RwSpinLock 

pub struct RwSpinLock {
    lock: AtomicIsize,
}
A busy-waiting reader-writer lock.

Fields

lock: AtomicIsize

Implementations

Source

impl RwSpinLock

pub const fn new() -> Self

Creates a new unlocked RwSpinLock.

pub fn read_lock(&self)

Waits until a read lock can be acquired.

pub unsafe fn read_unlock(&self)

Releases one read lock.

Safety

The caller must hold a read lock acquired from this RwSpinLock.

pub fn write_lock(&self)

Waits until a write lock can be acquired.

pub unsafe fn write_unlock(&self)

Releases the write lock.

Safety

The caller must hold the write lock acquired from this RwSpinLock.