pub struct RwSpinLocked<T> {
lock: RwSpinLock,
value: UnsafeCell<T>,
}Expand description
Protects a value with a busy-waiting reader-writer lock.
Multiple readers may access the value concurrently, while a writer has exclusive access. This lock is not reentrant and does not provide writer priority.
Fields
lock: RwSpinLockvalue: UnsafeCell<T>Implementations
Sourceimpl<T> RwSpinLocked<T>
impl<T> RwSpinLocked<T>
Sourcepub fn read_lock(&self) -> RwSpinLockReadGuard<'_, T>
pub fn read_lock(&self) -> RwSpinLockReadGuard<'_, T>
Locks the value for shared read access.
Sourcepub fn write_lock(&self) -> RwSpinLockWriteGuard<'_, T>
pub fn write_lock(&self) -> RwSpinLockWriteGuard<'_, T>
Locks the value for exclusive write access.